@@ -1,4 +1,5 @@
 
+
 test_that("pkgAvail throws warnings and errors for incorrect CRAN repos", {
   expect_warning(pkgAvail(repos = ""), "unable to access index for repository")
 
@@ -6,15 +7,14 @@ test_that("pkgAvail throws warnings and errors for incorrect CRAN repos", {
     all(is.matrix(x), dim(x)[2] == 17, names(x)[1:3] == c("Package", "Version", "Priority", "Depends"))
   }
 
-  skip_if_offline()
+  skip_if_offline(p3m())
+  
+  mran <- p3m("2024-01-02")
 
   expect_true(is.available.packages(
-    pkgAvail(repos = unname(MRAN()))
+    pkgAvail(repos = mran)
   ))
   expect_true(is.available.packages(
-    pkgAvail(repos = MRAN())
-  ))
-  expect_true(is.available.packages(
-    pkgAvail(repos = c(CRAN = "@CRAN@"))
+    pkgAvail(repos = mran)
   ))
 })
