@@ -2,12 +2,12 @@ if (interactive()) {library(testthat); Sys.setenv(NOT_CRAN = "true")}
 
 
 {
-  revolution_mran <- MRAN("2014-10-15")
-  if (!is.online(revolution_mran, tryHttp = FALSE)) {
+  mirror <- p3m("2024-01-02")
+  if (!is.online(mirror, tryHttp = FALSE)) {
     # Use http:// for older versions of R
-    revolution_mran <- sub("^https://", "http://", revolution_mran)
+    mirror <- sub("^https://", "https://", mirror)
   }
-  rvers = "3.2"
+  rvers <- "4.0"
   pkgs <- c("MASS")
   repo_root <- file.path(tempdir(), "miniCRAN", Sys.Date())
   new_repo_root <- file.path(tempdir(), "newMiniCRAN", Sys.Date())
@@ -22,22 +22,22 @@ names(types) <- c("win.binary")
 
 pkg_type <- names(types)
 
-for (pkg_type in names(types)) {
-  test_that(sprintf("makeRepo downloads %s files and builds PACKAGES file", pkg_type), {
-    # skip_on_cran()
-    skip_if_offline(revolution_mran)
+test_that("makeRepo downloads files and builds PACKAGES file", {
+  skip_if_offline(mirror)
+  # skip_on_cran()
+  for (pkg_type in names(types)) {
     
     # Create local miniCRAN
     # mockery::stub(makeRepo, "download_packages", mock_download_packages, depth = 1)
     # mockery::stub(updateRepoIndex, "write_packages", mock_write_packages, depth = 1)
     
-    pdb <- pkgAvail(repos = revolution_mran, type = pkg_type, Rversion = rvers, quiet = TRUE)
-    pkgList <- pkgDep(pkgs, availPkgs = pdb, repos = revolution_mran, type = pkg_type,
+    pdb <- pkgAvail(repos = mirror, type = pkg_type, Rversion = rvers, quiet = TRUE)
+    pkgList <- pkgDep(pkgs, availPkgs = pdb, repos = mirror, type = pkg_type,
                       suggests = FALSE, Rversion = rvers)
     prefix <- repoPrefix(pkg_type, Rversion = rvers)
     dir.create(repo_root, recursive = TRUE, showWarnings = FALSE)
     
-    ret <- makeRepo(pkgList, path = repo_root, repos = revolution_mran, 
+    ret <- makeRepo(pkgList, path = repo_root, repos = mirror, 
                     type = pkg_type, quiet = TRUE, Rversion = rvers)
     
     expect_type(ret, "character")
@@ -83,7 +83,7 @@ for (pkg_type in names(types)) {
       )
     )
     
-  })
-}
+  }
+})
 
 unlink(repo_root, recursive = TRUE)
