@@ -2,6 +2,7 @@ test_that("is online", {
   skip_on_cran()
  
   # Should always be TRUE, but will trigger github action failure if 
-  # MRAN is offline
+  # p3m is offline
   expect_true(is.online())
+  expect_true(is.online(p3m("2024-01-02")))
 })
\ No newline at end of file
